==> patch-2.5.3.19.zip: app/views/sync/sharedWithMe.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<span ng-controller="ShareWithController" xmlns="http://www.w2.org/1999/html">
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><?=$data['title']?></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main">
    <span class="hide currentPage"><?='trash'?></span>
    <span class="hide csrf_token"><?=$data['csrf_token']?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 status" style="display: none">
            <div class="statusMessage text-center"></div>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 filePanel" block-ui="myBlockUI">
            <div class="panel panel-default no-box-shadow panel-actions">
                <div class="panel-body" style="height: 40px;">
                    <ul class="nav navbar-nav pull-right nav-actions">
                        <li><a class="viewAction toolTip" ng-click="view()" data-toggle="tooltip" data-placement="top" title="View" style="display: none" href="javascript:;"><i class="fa fa-eye"></i></a></li>
                        <li><a class="downloadAction toolTip" ng-click="download('')" data-toggle="tooltip" data-placement="top" title="Download" style="display: none" href="javascript:;"><i class="fa fa-download"></i></a></li>
                    </ul>
                </div>
            </div>
            <div class="panel panel-default files-panel no-box-shadow" ng-if="items.length > 0">
                <div class="table-responsive">
                    <table class="table table-striped table-hover files-table">
                        <thead>
                        <tr>
                            <th class="clickAble" ng-click="sortType = 'fileName'; sortReverse = !sortReverse">
                                Name
                                <span ng-show="sortType == 'fileName' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'fileName' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <th class="clickAble" ng-click="sortType = 'sharedTime'; sortReverse = !sortReverse">
                                Shared By
                                <span ng-show="sortType == 'sharedTime' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'sharedTime' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <th class="clickAble" ng-click="sortType = 'sharedTime'; sortReverse = !sortReverse">
                                Valid Until
                                <span ng-show="sortType == 'sharedTime' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'sharedTime' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <!--<th class="clickAble" ng-click="sortType = 'devicePath'; sortReverse = !sortReverse">
                                Path
                                <span ng-show="sortType == 'devicePath' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'devicePath' && sortReverse" class="fa fa-caret-down"></span>
                            </th>-->
                        </tr>
                        </thead>
                        <tbody id="selectable"
                               selectable="tr"
                               selectable-list="items"
                               selectable-out="selected"
                               selectable-options="{filter:'tr'}"
                               selectable-events="{start:'selectionStart($selected)', stop:'selectionStop($selected)'}"
                               block-ui="myBlockUI"
                               context-menu="menuOptions">
                        <tr ng-repeat="value in items | orderBy:sortType:sortReverse">
                            <td data-name="{{value.$$hashKey}}" ng-cloak><i class="fa fa-{{ value.icon }} fa-1x"></i> <a style="cursor: pointer; color: #585f69;"><span ng-bind-html="value.fileName | charLimit"></span></a></td>
                            <td ng-cloak> {{ value.sharedBy }} </td>
                            <td ng-cloak> {{ value.validUntil }} </td>
                            <!--<td ng-cloak>{{ value.devicePath }}</td>-->
                        </tr>
                        </tbody>
                    </table>
                </div>
            </div>
            <div class="text-center status" style="display: none;">
                <h3>There are no files or folders</h3>
            </div>
            <div class="modal fade" id="share" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                            <h4 class="modal-title" id="myModalLabel">Share Details</h4>
                        </div>
                        <div class="modal-body shareLoading">
                            <span>Loading ...</span>
                        </div>
                        <div class="modal-body shareBody" style="display: none;">
                            <div class="mt-md mb-md">
                                <div class="shareLinkBlock" style="display: none;">
                                    <h4>
                                        Share the below link to share the file:
                                        <a ng-click="sendEmailShareLink()" class="clickAble pull-right sendEmailShareLink"><i class="fa fa-envelope"></i></a>
                                    </h4>
                                    <h5 class="shareLink" style="word-wrap: break-word;"></h5>
                                </div>
                                <div class="form-group sendEmailShareForm hide">
                                    <label for="emails">Emails</label>
                                    <textarea name="emails" ng-model="emails" class="form-control" id="emails"> </textarea>
                                    <br/>
                                    <a ng-click="sendShareEmail(emails)" class="btn btn-small btn-default shareEmailLinkSendBtn"> Send</a>
                                </div>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                            <a ng-click="unShareFile()" style="display: none;" class="unShareBtn btn btn-danger">Un-Share</a>
                        </div>
                    </div>
                </div>
            </div>
<!--modal--><?php if($data['popup'] == 'visible') { ?>
            <div class="modal fade" id="changePasswordForGuest" role="dialog" data-keyboard="false" data-backdrop="static">
    <div class="modal-dialog">
    
      <!-- Modal content-->
      <div class="modal-content">
      <?=
                        Form::open(array(
                            'ng-submit' => 'changePasswordForGuest()',
                            'method' => 'post',
                            'id' => 'changePasswordFormGuest',
                            'csrf' => $data['csrf_token'],
                            'autocomplete' => 'off',
                            'data-parsley-validate' => true
                        ));
                    ?>
        <div class="modal-header">
          
          <h4 class="modal-title">Change Password</h4>
        </div>
        <div class="modal-body">
          
                        <div class="form-group">
                            <label for="passwordGuest">Password</label>
                            <input type="password" name="passwordGuest" class="form-control" id="passwordGuest" placeholder="Enter a Password" data-parsley-minlength="6" data-parsley-required data-parsley-pattern="(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?!.*[!#\$%&\?])^\D" data-parsley-pattern-message="Password Should Contain one number, one uppercase, one lowercase and cannot start with a number (Special Characters Allowed '@' '.')" data-parsley-trigger="change" required>
                            
                        </div>
                        <div class="form-group">
                            <label for="rePasswordGuest">Re Type Password</label>
                            <input type="password" name="rePasswordGuest" class="form-control" id="rePasswordGuest" placeholder="Re-Type the password" data-parsley-equalto="#passwordGuest" data-parsley-trigger="change" data-parsley-required>
                        </div>
                        
                        
                    
        </div>
        <div class="modal-footer">
          <p style="float: left;">Change password to proceed further.</p>
          <a class="btn btn-default" type="button" href="<?=URL::basePath('logout')?>">Cancel</a>
          <button type="submit" id="changePasswordBtnGuest" class="btn btn-primary"><?=Language::show('save', 'keywords');?></button>
        </div>
        <?=
                        Form::close();
                    ?>
      </div>
      
    </div>
  </div>
  <?php } ?>
            <!--modal-->
            <!--<div class="modal" id="paraviewContainer" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                            <h5 class="modal-title">Loading ...</h5>
                        </div>
                        <br/><br/>
                        <div class="modal-body">
                            <div class="pageContainer" style="display: none;"></div>
                            <div class="pdfContainer" style="display: none;"></div>
                            <div class="excelContainer" style="display: none;"></div>
                            <div class="content" style="display: none;"></div>
                            <div class="imageViewer" style="display: none;"></div>
                            <div class="paraviewLoading" style="margin-top: 15%">
                                <img width="5%" src="<?=Url::templatePath('default/images/gears.gif');?>" />
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                            <button type="button" class="btn btn-primary">Save changes</button>
                        </div>
                    </div>
                </div>
            </div>-->
            <div class="modal" id="paraviewContainer" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" style="background-color:white;">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                            <h5 class="modal-title">Loading ...</h5>
                        </div>
                        <br/><br/>
                        <div class="modal-body">
                            <div class="pageContainer" style="background-color: white;display: none;"></div>
                            <div class="pdfContainer" style="display: none;"></div>
                            <div class="excelContainer" style="background-color: white;display: none;"></div>
                            <div class="content" style="text-align: -webkit-auto;display: none;"></div>
                            <div class="imageViewer" style="display: none;"></div>
                            <div class="pptxViewer" style="background-color: white;display: none;"></div>
                            <div class="paraviewLoading" style="margin-top: 15%">
                                <img width="5%" src="<?=Url::templatePath('default/images/gears.gif');?>" />
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                            <button type="button" class="btn btn-primary">Save changes</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
</span>
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/ShareWithController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
<script type="text/javascript">
   <?php if($data['popup'] == 'visible') { ?>
$('#changePasswordForGuest').modal('show');
    <?php } ?>
</script>

==> patch-2.5.4.12.zip: app/views/sync/sharedWithMe.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<span ng-controller="ShareWithController" xmlns="http://www.w2.org/1999/html">
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><?=$data['title']?></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main">
    <span class="hide currentPage"><?='trash'?></span>
    <span class="hide csrf_token"><?=$data['csrf_token']?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <!--<div class="col-lg-11 col-md-11 col-sm-11 status" style="display: none">
            <div class="statusMessage text-center"></div>
        </div>-->
        <div class="col-lg-11 col-md-11 col-sm-11 filePanel" block-ui="myBlockUI">
            <div class="panel panel-default no-box-shadow panel-actions">
                <div class="panel-body" style="height: 40px;">
                    <ul class="nav navbar-nav pull-right nav-actions">
                        <li><a class="viewAction toolTip" ng-click="view()" data-toggle="tooltip" data-placement="top" title="View" style="display: none" href="javascript:;"><i class="fa fa-eye"></i></a></li>
                        <li><a class="downloadAction toolTip" ng-click="download('')" data-toggle="tooltip" data-placement="top" title="Download" style="display: none" href="javascript:;"><i class="fa fa-download"></i></a></li>
                    </ul>
                </div>
            </div>
            <div class="panel panel-default files-panel no-box-shadow" ng-if="items.length > 0">
                <div class="table-responsive">
                    <table class="table table-striped table-hover files-table">
                        <thead>
                        <tr>
                            <th class="clickAble" ng-click="sortType = 'fileName'; sortReverse = !sortReverse">
                                Name
                                <span ng-show="sortType == 'fileName' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'fileName' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <th class="clickAble" ng-click="sortType = 'sharedBy'; sortReverse = !sortReverse">
                                Shared By
                                <span ng-show="sortType == 'sharedBy' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'sharedBy' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
			    <th class="clickAble" ng-click="sortType = 'sharedTime'; sortReverse = !sortReverse">
                                Shared On
                                <span ng-show="sortType == 'sharedTime' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'sharedTime' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <th class="clickAble" ng-click="sortType = 'validUntilTime'; sortReverse = !sortReverse">
                                Valid Until
                                <span ng-show="sortType == 'validUntilTime' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'validUntilTime' && sortReverse" class="fa fa-caret-down"></span>
                            </th>
                            <!--<th class="clickAble" ng-click="sortType = 'devicePath'; sortReverse = !sortReverse">
                                Path
                                <span ng-show="sortType == 'devicePath' && !sortReverse" class="fa fa-caret-up"></span>
                                <span ng-show="sortType == 'devicePath' && sortReverse" class="fa fa-caret-down"></span>
                            </th>-->
                        </tr>
                        </thead>
                        <tbody id="selectable"
                               selectable="tr"
                               selectable-list="items"
                               selectable-out="selected"
                               selectable-options="{filter:'tr'}"
                               selectable-events="{start:'selectionStart($selected)', stop:'selectionStop($selected)'}"
                               block-ui="myBlockUI"
                               context-menu="menuOptions">
                        <tr ng-repeat="value in items | orderBy:sortType:sortReverse">
                            <td data-name="{{value.$$hashKey}}" ng-cloak><i class="fa fa-{{ value.icon }} fa-1x"></i> <a style="cursor: pointer; color: #585f69;"><span ng-bind-html="value.fileName | charLimit"></span></a></td>
                            <td ng-cloak> {{ value.sharedBy }} </td>
			    <td ng-cloak> {{ value.sharedTimeDate }} </td>
                            <td ng-cloak> {{ value.validUntil }} </td>
                            <!--<td ng-cloak>{{ value.devicePath }}</td>-->
                        </tr>
                        </tbody>
                    </table>
                </div>
            </div>
            <div class="text-center status" style="display: none;">
                <h3>There are no files or folders</h3>
            </div>
            <div class="modal fade" id="share" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h4 class="modal-title" id="myModalLabel">Share Details</h4>				
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                        </div>
                        <div class="modal-body shareLoading">
                            <span>Loading ...</span>
                        </div>
                        <div class="modal-body shareBody" style="display: none;">
                            <div class="mt-md mb-md">
                                <div class="shareLinkBlock" style="display: none;">
                                    <h4>
                                        Share the below link to share the file:
                                        <a ng-click="sendEmailShareLink()" class="clickAble pull-right sendEmailShareLink"><i class="fa fa-envelope"></i></a>
                                    </h4>
                                    <h5 class="shareLink" style="word-wrap: break-word;"></h5>
                                </div>
                                <div class="form-group sendEmailShareForm hide">
                                    <label for="emails">Emails</label>
                                    <textarea name="emails" ng-model="emails" class="form-control" id="emails"> </textarea>
                                    <br/>
                                    <a ng-click="sendShareEmail(emails)" class="btn btn-small btn-default shareEmailLinkSendBtn"> Send</a>
                                </div>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                            <a ng-click="unShareFile()" style="display: none;" class="unShareBtn btn btn-danger">Un-Share</a>
                        </div>
                    </div>
                </div>
            </div>
<!--modal--><?php if($data['popup'] == 'visible') { ?>
            <div class="modal fade" id="changePasswordForGuest" role="dialog" data-keyboard="false" data-backdrop="static">
    <div class="modal-dialog">    
      <!-- Modal content-->
      <div class="modal-content">
      <?=
                        Form::open(array(
                            'ng-submit' => 'changePasswordForGuest()',
                            'method' => 'post',
                            'id' => 'changePasswordFormGuest',
                            'csrf' => $data['csrf_token'],
                            'autocomplete' => 'off',
                            'data-parsley-validate' => true
                        ));
                    ?>
        <div class="modal-header">          
          <h4 class="modal-title">Change Password</h4>
        </div>
        <div class="modal-body">          
                        <div class="form-group">
                            <label for="passwordGuest">Password</label>
                            <input type="password" name="passwordGuest" class="form-control" id="passwordGuest" placeholder="Enter a Password" data-parsley-minlength="6" data-parsley-required data-parsley-pattern="(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?!.*[!#\$%&\?])^\D" data-parsley-pattern-message="Password Should Contain one number, one uppercase, one lowercase and cannot start with a number (Special Characters Allowed '@' '.')" data-parsley-trigger="change" required>                            
                        </div>
                        <div class="form-group">
                            <label for="rePasswordGuest">Re Type Password</label>
                            <input type="password" name="rePasswordGuest" class="form-control" id="rePasswordGuest" placeholder="Re-Type the password" data-parsley-equalto="#passwordGuest" data-parsley-trigger="change" data-parsley-required>
                        </div>                                                                    
        </div>
        <div class="modal-footer">
          <p style="float: left;">Change password to proceed further.</p>
          <a class="btn btn-default" type="button" href="<?=URL::basePath('logout')?>">Cancel</a>
          <button type="submit" id="changePasswordBtnGuest" class="btn btn-primary"><?=Language::show('save', 'keywords');?></button>
        </div>
        <?=
                        Form::close();
                    ?>
      </div>      
    </div>
  </div>
  <?php } ?>
            <!--modal-->
            <!--<div class="modal" id="paraviewContainer" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                            <h5 class="modal-title">Loading ...</h5>
                        </div>
                        <br/><br/>
                        <div class="modal-body">
                            <div class="pageContainer" style="display: none;"></div>
                            <div class="pdfContainer" style="display: none;"></div>
                            <div class="excelContainer" style="display: none;"></div>
                            <div class="content" style="display: none;"></div>
                            <div class="imageViewer" style="display: none;"></div>
                            <div class="paraviewLoading" style="margin-top: 15%">
                                <img width="5%" src="<?=Url::templatePath('default/images/gears.gif');?>" />
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                            <button type="button" class="btn btn-primary">Save changes</button>
                        </div>
                    </div>
                </div>
	    </div>-->
	    <div class="modal" id="paraviewContainer" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" style="background-color:white;">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
			    <h5 class="modal-title">Loading ...</h5>
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>                            
                        </div>
                        <br/><br/>
                        <div class="modal-body">
                            <div class="pageContainer" style="background-color: white;display: none;"></div>
                            <div class="pdfContainer" style="display: none;"></div>
                            <div class="excelContainer" style="background-color: white;display: none;"></div>
                            <div class="content" style="text-align: -webkit-auto;display: none;"></div>
                            <div class="imageViewer" style="display: none;"></div>
                            <div class="pptxViewer" style="background-color: white;display: none;"></div>
                            <div class="paraviewLoading" style="margin-top: 15%">
                                <img width="5%" src="<?=Url::templatePath('default/images/gears.gif');?>" />
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                            <button type="button" class="btn btn-primary">Save changes</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
</span>
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/ShareWithController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
<script type="text/javascript">
   <?php if($data['popup'] == 'visible') { ?>
$('#changePasswordForGuest').modal('show');
    <?php } ?>
</script>
